@@ -38,11 +38,11 @@ static int rule_count = 0;
 #define CONFIGFILE	"/etc/access.conf"
 #define DEFAULT_INTERFACE "! lo"
 
-#ifdef MACH_IPAQ
-#define IPTABLES_CMD "/usr/sbin/iptables"
-#else
-#define IPTABLES_CMD "/sbin/iptables"
-#endif
+#define IPTABLES_CMD1 "/usr/sbin/iptables"
+#define IPTABLES_CMD2 "/sbin/iptables"
+#define IPTABLES_CMD3 "/usr/local/sbin/iptables"
+
+static const char* IPTABLES_CMD = NULL;
 
 /* forwared definitions */
 
@@ -134,7 +134,12 @@ do_load_rules(void)
 void
 do_clear(void)
 {
-	system(IPTABLES_CMD " --flush");
+	char* cmd = g_strdup_printf("%s %s",IPTABLES_CMD,"--flush");
+	system(cmd);
+	g_free(cmd);
+	cmd = g_strdup_printf("%s %s",IPTABLES_CMD,"-P INPUT ACCEPT"); /* reset input policy */
+	system(cmd);
+	g_free(cmd);
 	g_free(rule_info);
 	rule_info = NULL;
 	rule_count = 0;
@@ -150,7 +155,13 @@ do_rules_apply()
 	const gchar *target;
 	int i;
 	
-	system(IPTABLES_CMD " --flush"); /* cleans all existing iptables settings */
+	/* cleans all existing iptables settings */
+	cmd = g_strdup_printf("%s %s",IPTABLES_CMD,"--flush");
+	system(cmd);
+	g_free(cmd);
+	cmd = g_strdup_printf("%s %s",IPTABLES_CMD,"-P INPUT ACCEPT"); /* reset input policy */
+	system(cmd);
+	g_free(cmd);
 
 	for (i=0;i<rule_count;i++)
 	{	
@@ -345,8 +356,8 @@ send_message (pkcontent_t ctype, rule_t *rule)
 static void
 do_shutdown()
 {
-	system(IPTABLES_CMD " --flush"); /* cleans all existing iptables settings */
-	system(IPTABLES_CMD " -P INPUT ACCEPT"); /* reset input policy */
+//	system(IPTABLES_CMD " --flush"); /* cleans all existing iptables settings */
+//	system(IPTABLES_CMD " -P INPUT ACCEPT"); /* reset input policy */
 }
 
 static int
@@ -397,6 +408,25 @@ wait_message ()
 }
 
 
+static void
+do_change_cfg_load(gboolean doit)
+{
+	int fh;
+	if (doit)
+	{
+		if ((fh = open(LOADRULES_MARK,O_CREAT | O_RDWR | O_TRUNC)) < 0)
+			perror("Cannot save setting.");
+		else
+			close(fh);
+	}
+	else
+	{
+		if (remove(LOADRULES_MARK) < 0)
+			perror("Cannot save setting.");
+	}
+}
+
+
 static void
 do_command (pkcommand_t command, rule_t rule)
 {
@@ -427,6 +457,12 @@ do_command (pkcommand_t command, rule_t rule)
 	case CMD_SHUTDOWN:
 		do_shutdown();
 	break;
+	case CMD_CFG_LOAD:
+		do_change_cfg_load(TRUE);
+	break;
+	case CMD_CFG_DONTLOAD:
+		do_change_cfg_load(FALSE);
+	break;
 	default:
 	break;
 	}
@@ -442,9 +478,17 @@ suidloop (int csock)
 {
 	sock = csock;
 
+	if (!access(IPTABLES_CMD1,X_OK))
+		IPTABLES_CMD = IPTABLES_CMD1;
+	else if (!access(IPTABLES_CMD2,X_OK))
+		IPTABLES_CMD = IPTABLES_CMD2;
+	else if (!access(IPTABLES_CMD3,X_OK))
+		IPTABLES_CMD = IPTABLES_CMD3;
+	
 	while (wait_message ()) ;
 		
 	close (sock);
+	unlink (PK_SOCKET);
 
 	return 0;
 }
