@@ -75,7 +75,6 @@
 #define HELPMESSAGE "GPE-Shield\nVersion " VERSION \
 		"\nGPE desktop firewall\n\nflorian.boor@kernelconcepts.de"
 #define NOHELPMESSAGE N_("Displaying help failed.")
-#define LOADRULES_MARK ".gpe/gpe-shield-load"
 
 /* --- module global variables --- */
 
@@ -504,20 +503,24 @@ on_help_clicked (GtkWidget * w)
 void
 change_network_control (GtkWidget * w)
 {
-	int fh;
-	char *file = g_strdup_printf("%s/%s",g_get_home_dir(),LOADRULES_MARK);
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w)))
-	{
-		if ((fh = open(file,O_CREAT)) < 0)
-			gpe_perror_box(_("Cannot save setting."));
-		else
-			close(fh);
-	}
+		send_message(PK_COMMAND,CMD_CFG_LOAD,NULL);
 	else
-	{
-		if (remove(file) < 0)
-			gpe_perror_box(_("Cannot save setting."));
-	}
+		send_message(PK_COMMAND,CMD_CFG_DONTLOAD,NULL);
+}
+
+
+gboolean
+get_network_control (void)
+{
+	gboolean result;
+	
+	if (!access(LOADRULES_MARK,F_OK))
+		result = TRUE;
+	else
+		result = FALSE;
+	
+	return result;
 }
 
 
@@ -902,9 +905,10 @@ create_fMain (void)
   free(tmp);
   gtk_box_pack_start(GTK_BOX(vbox),cur,FALSE,TRUE,0);	
   
-  cur = gtk_check_button_new_with_label(_("Start network control on login"));
+  cur = gtk_check_button_new_with_label(_("Start network control on system start"));
   gtk_box_pack_start(GTK_BOX(vbox),cur,FALSE,TRUE,0);
-	g_signal_connect_after (G_OBJECT (cur), "toggled",
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cur),get_network_control());
+  g_signal_connect_after (G_OBJECT (cur), "toggled",
 			  G_CALLBACK (change_network_control), NULL);
   
   g_signal_connect(G_OBJECT (fMain),"destroy",gtk_main_quit,NULL);
